#!/bin/sh
# install script for schat // 2019-10-04 // yargo@circumlunar.space
# please modify the following variables according to your local needs!

# source directory; pwd -P only works if this script is started here!
srcdir=`pwd -P`
# explicit alternative:
#srcdir=/var/local/schat
# common path for local executables:
bindir=/usr/local/bin
# common directory for globally writable(!) files
# (must exist and be writable by everybody):
shrdir=/var/local/share
# names of files containing messages and enter/leave notifications:
text=schatfile.txt
bang=schatbang.txt

# #### don't touch anything below unless you know what you are doing! ####

# main scripts, suffix .sh will be removed for executables
schats=schat.sh
archs=schatarch.sh
# template for ~/.schatnrc
tmpl=schatnrc.colors

cat <<EOT
$0, trying to install schat on this system...
- sources should be in $srcdir
- executables will be placed in $bindir
- message files will be in $shrdir
  ($text and $bang)
These settings can be modified in the source, if need be.
Please hit RETURN if you are fine with this, else abort with CTRL-C!
EOT
read _

echo "checking $bindir ..."
if ! test -d "$bindir" -a -w "$bindir" -a -x "$bindir"
then cat <<EOT
$bindir must be directory & writable & executable!
(you are root or sudoing or have permissions, right??)
EOT
 exit 1
fi

echo "checking $srcdir ..."
if ! test -d "$srcdir" -a -r "$srcdir"
then cat <<EOT
$srcdir must be readable directory!
EOT
 exit 1
fi

echo "checking $shrdir ..."
if ! test -d "$shrdir" -a -r "$shrdir" -a -w "$shrdir" -a -x "$shrdir"
then cat <<EOT
$shrdir must be read&write&executable!
EOT
 exit 1
fi

# sed command to set up file names
sedcmd="s,^chat=.*$,chat=$shrdir/$text,;s,^bang=.*$,bang=$shrdir/$bang,"
echo "installing executable scripts:"
# executable without suffix
xeq="$bindir/${schats%.*}"
echo "- $schats to $xeq ..."
sed -e "$sedcmd" "$srcdir/$schats" >"$xeq"
chmod 755 "$xeq"
xeq="$bindir/${archs%.*}"
echo "- $archs to $xeq ..."
sed -e "$sedcmd" "$srcdir/$archs" >"$xeq"
chmod 755 "$xeq"

echo "installing message files ..."

mf="$shrdir/$text"
if test -e "$mf"
then echo "$mf already exists, keeping!"
else echo "# schat text file, installed `date`" >"$mf"
fi
chmod 666 "$shrdir/$text"

mf="$shrdir/$bang"
if test -e "$mf"
then echo "$mf already exists, keeping!"
else echo "# schat bang file, installed `date`" >"$mf"
fi
chmod 666 "$shrdir/$bang"

echo "installing template $shrdir/$tmpl ..."
mf="$shrdir/$tmpl"
if test -e "$mf"
then echo "$mf already exists, keeping!"
else sed -e "$sedcmd" "$srcdir/$tmpl" >"$mf"
fi
chmod 644 "$shrdir/$tmpl"

cat <<EOT
done.
Please make sure all users can read and write files in
 $shrdir/ !
EOT
