#!/bin/sh
# mini shell chat, helper script for archiving
info="shell chat archiver // 2018-12-12 yargo@circumlunar.space"

# files: chat contains the entered text, bang the login/logout information
# (can be defined independently by environment variables)
# (do not rename/reformat! will be modified by install.sh)
chat=
bang=
# suffix for lockfiles
lksuffix=lock

now=`date -u +%y%m%d`
# archive file names
achat=$chat-$now
abang=$bang-$now

setlock() {
 local lf
 lf="$1.$lksuffix"
 if test -f "$lf"
 then
  echo :: $1 is locked, lockfile contents:
  sed -e 's/^/::  /' "$lf"
  echo :: please verify and remove if possible, aborting now
  exit 9
 fi
# put timestamp, script name and PID into lockfile
 cat <<EOT > "$lf"
`date -u`
$0 (PID $$)
EOT
}

remlock() {
 local lf
 lf="$1.$lksuffix"
 /bin/rm -f "$lf"
}

help() {
cat <<EOT

:: $info ::
 usage: $0 <tail>
 will append the schat files
  $chat
  $bang
 to files named
  $achat
  $abang
 while keeping the last <tail> lines in the originals
 (<tail> must be larger than 9)
EOT
}

# chat and log files at least must be readable
if test ! -r $chat
 then
 echo "$chat not readable!"
 exit 1
fi
if test ! -r $bang
 then
 echo "$bang not readable!"
 exit 1
fi

# suppress everything except numbers in first argument
tn=`echo $1 | tr -c -d 0123456789`
# and make sure it's not empty but reasonably large
tn=${tn:-0}
if test $tn -lt 9
then help
 exit
else echo :: keeping last $tn lines in current files
fi

# lock both files before archiving
setlock $chat
setlock $bang

# try to archive chatfile
if cat $chat >>$achat
then echo :: $chat archived
# and get back $tn lines from archive
 tail -n $tn $achat >$chat
else echo :: archiving $chat failed, kept
fi

# same procedure for logfile
if cat $bang >>$abang
then echo :: $bang archived
 tail -n $tn $abang >$bang
else echo :: archiving $bang failed, kept
fi

# release locks on both files
remlock $bang
remlock $chat

echo :: done.
